OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visualizador",
    "Simple file viewer with slideshow for media" : "Um visualizador de ficheiros com diaporamas para multimédia",
    "Your browser does not support audio." : "O seu navegador não suporta áudio.",
    "Error loading {name}" : "Erro ao carregar {name}",
    "Image saved" : "Imagem guardada",
    "Unsaved changes" : "Modificações não guardadas",
    "Your browser does not support videos." : "O seu navegador não suporta vídeos.",
    "Edit" : "Editar",
    "Open sidebar" : "Abrir barra lateral",
    "Download" : "Transferir",
    "Delete" : "Apagar",
    "View" : "Ver",
    "Name" : "Nome",
    "Save" : "Guardar",
    "Back" : "Anterior",
    "Loading …" : "A carregar...",
    "Reset" : "Reiniciar",
    "Cancel" : "Cancelar",
    "Apply" : "Aplicar",
    "Warning" : "Aviso",
    "Confirm" : "Confirmar",
    "Undo" : "Desfazer",
    "Redo" : "Repetir",
    "Original" : "Original",
    "Custom" : "Personalizado",
    "Value" : "Valor",
    "Image" : "Imagem",
    "Text" : "Texto",
    "Size" : "Altura",
    "Name is required." : "Nome é obrigatório.",
    "Quality" : "Qualidade",
    "Menu" : "Menu",
    "Height" : "Altura"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
